@@ -30,6 +30,7 @@ LAUNCHES = "launches"
 STACK = "stack"
 STACKS = "stacks"
 SPOKE_LOCAL_PORTFOLIOS = "spoke-local-portfolios"
+IMPORTED_PORTFOLIOS = "imported-portfolios"
 LAMBDA_INVOCATIONS = "lambda-invocations"
 ASSERTIONS = "assertions"
 WORKSPACES = "workspaces"
@@ -56,6 +57,7 @@ ACTIONS = "actions"
 LAUNCH = "launch"
 LAMBDA_INVOCATION = "lambda-invocation"
 SPOKE_LOCAL_PORTFOLIO = "spoke-local-portfolio"
+IMPORTED_PORTFOLIO = "imported-portfolio"
 ACTION = "action"
 
 AFFINITY = "affinity"
@@ -139,6 +141,7 @@ ALL_SECTION_NAMES = [
     LAUNCHES,
     STACKS,
     SPOKE_LOCAL_PORTFOLIOS,
+    IMPORTED_PORTFOLIOS,
     LAMBDA_INVOCATIONS,
     CODE_BUILD_RUNS,
     ASSERTIONS,
@@ -170,6 +173,7 @@ ALL_SECTION_NAME_SINGULAR_AND_PLURAL_LIST = [
     (LAUNCH, LAUNCHES),
     (STACK, STACKS),
     (SPOKE_LOCAL_PORTFOLIO, SPOKE_LOCAL_PORTFOLIOS),
+    (IMPORTED_PORTFOLIO, IMPORTED_PORTFOLIOS),
     (LAMBDA_INVOCATION, LAMBDA_INVOCATIONS),
     (CODE_BUILD_RUN, CODE_BUILD_RUNS),
     (ASSERTION, ASSERTIONS),
@@ -203,6 +207,7 @@ SECTION_SINGULAR_TO_PLURAL = {
     LAUNCH: LAUNCHES,
     STACK: STACKS,
     SPOKE_LOCAL_PORTFOLIO: SPOKE_LOCAL_PORTFOLIOS,
+    IMPORTED_PORTFOLIO: IMPORTED_PORTFOLIOS,
     LAMBDA_INVOCATION: LAMBDA_INVOCATIONS,
     CODE_BUILD_RUN: CODE_BUILD_RUNS,
     ASSERTION: ASSERTIONS,
@@ -256,6 +261,7 @@ INITIALISER_STACK_NAME_SSM_PARAMETER = "service-catalog-puppet-initialiser-stack
 SECTIONS_THAT_SUPPORT_CONDITIONS = [
     LAUNCHES,
     SPOKE_LOCAL_PORTFOLIOS,
+    IMPORTED_PORTFOLIOS,
     STACKS,
     APPS,
     WORKSPACES,
@@ -273,6 +279,7 @@ DEPLOY_TO_NAMES = {
     LAUNCHES: "deploy_to",
     STACKS: "deploy_to",
     SPOKE_LOCAL_PORTFOLIOS: "share_with",
+    IMPORTED_PORTFOLIOS: "share_with",
     LAMBDA_INVOCATIONS: "invoke_for",
     CODE_BUILD_RUNS: "run_for",
     ASSERTIONS: "assert_for",
@@ -394,7 +401,11 @@ SPOKE_SCHEDULER_THREADS_OR_PROCESSES_DEFAULT = SCHEDULER_THREADS_OR_PROCESSES_DE
 SPOKE_SCHEDULER_ALGORITHM_DEFAULT = SCHEDULER_ALGORITHM_DEFAULT
 
 
-CACHE_LEVEL_LOW = "CACHE_LEVEL_LOW"
-CACHE_LEVEL_NORMAL = "CACHE_LEVEL_NORMAL"
-CACHE_LEVEL_HIGH = "CACHE_LEVEL_HIGH"
+CACHE_LEVEL_RUN = "CACHE_LEVEL_RUN"
+CACHE_LEVEL_TASK = "CACHE_LEVEL_TASK"
+CACHE_LEVEL_PERMANENT = "CACHE_LEVEL_PERMANENT"
 CACHE_LEVEL_NO_CACHE = "CACHE_LEVEL_NO_CACHE"
+
+CACHE_LEVEL_DEFAULT = CACHE_LEVEL_RUN
+
+WAS_A_SPOKE_LOCAL_PORTFOLIO_DEFAULT = False
