@@ -21,7 +21,7 @@ class DoAssertTask(tasks.TaskWithParameters):
     actual = luigi.DictParameter()
 
     requested_priority = luigi.IntParameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
@@ -69,6 +69,3 @@ class DoAssertTask(tasks.TaskWithParameters):
             raise Exception(ddiff)
         else:
             self.write_empty_output()
-
-
-#
