@@ -21,7 +21,7 @@ class DoInvokeLambdaTask(tasks.TaskWithParameters):
     manifest_file_path = luigi.Parameter()
 
     section_name = constants.LAMBDA_INVOCATIONS
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     @property
     def item_name(self):
