@@ -19,7 +19,7 @@ class CreateAssociationsForSpokeLocalPortfolioTask(tasks.TaskWithReference):
     portfolio = luigi.Parameter()
 
     associations = luigi.ListParameter(default=[])
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
