@@ -12,7 +12,7 @@ class DisassociateProductsFromPortfolio(tasks.TaskWithReference):
     region = luigi.Parameter()
     portfolio = luigi.Parameter()
     portfolio_task_reference = luigi.Parameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
