@@ -15,7 +15,7 @@ class ShareAndAcceptPortfolioForAccountTask(tasks.TaskWithReference):
     share_principals = luigi.BoolParameter()
     portfolio_task_reference = luigi.Parameter()
     describe_portfolio_shares_task_ref = luigi.Parameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
