@@ -25,11 +25,9 @@ from servicecatalog_puppet import (
     config,
     constants,
     environmental_variables,
-    remote_config,
     serialisation_utils,
 )
 from servicecatalog_puppet.waluigi import runner_factory
-from servicecatalog_puppet.workflow import tasks
 
 
 logger = logging.getLogger(constants.PUPPET_LOGGER_NAME)
@@ -101,8 +99,8 @@ def run_tasks(
 
     logger.info(f"About to run workflow with {num_workers} workers")
 
-    if not (running_exploded or is_list_launches):
-        tasks.print_stats()
+    # if not (running_exploded or is_list_launches):
+    # tasks.print_stats()
 
     output_cache_starting_point = config.get_output_cache_starting_point()
     logger.info("CHECKING output_cache_starting_point")
@@ -125,12 +123,8 @@ def run_tasks(
         config.get_scheduler_algorithm(),
     )
 
-    task_idempotency_token = os.environ.get(
-        environmental_variables.TASK_IDEMPOTENCY_TOKEN
-    )
-    run_idempotency_token = os.environ.get(
-        environmental_variables.RUN_IDEMPOTENCY_TOKEN
-    )
+    drift_token = os.environ.get(environmental_variables.DRIFT_TOKEN)
+    run_token = os.environ.get(environmental_variables.RUN_TOKEN)
 
     has_failures = len(glob("results/failure/*", recursive=True))
     has_spoke_failures = False
@@ -138,7 +132,7 @@ def run_tasks(
     if execution_mode == constants.EXECUTION_MODE_HUB:
         logger.info("Checking spoke executions...")
         all_run_deploy_in_spoke_tasks = glob(
-            f"output/RunDeployInSpokeTask/**/{run_idempotency_token}.json",  # TODO EPF
+            f"output/RunDeployInSpokeTask/**/{run_token}.json",  # TODO EPF
             recursive=True,
         )
         n_all_run_deploy_in_spoke_tasks = len(all_run_deploy_in_spoke_tasks)
@@ -185,19 +179,19 @@ def run_tasks(
 
     dry_run_tasks = (
         glob(
-            f"output/ProvisionProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
+            f"output/ProvisionProductDryRunTask/**/{drift_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/TerminateProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
+            f"output/TerminateProductDryRunTask/**/{drift_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/ProvisionStackDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
+            f"output/ProvisionStackDryRunTask/**/{drift_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/TerminateStackDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
+            f"output/TerminateStackDryRunTask/**/{drift_token}.json",  # TODO EPF
             recursive=True,
         )
     )
@@ -258,7 +252,7 @@ def run_tasks(
         elif is_list_launches == "json":
             results = dict()
             for filename in glob(
-                f"output/ProvisionProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
+                f"output/ProvisionProductDryRunTask/**/{drift_token}.json",  # TODO EPF
                 recursive=True,
             ):
                 result = serialisation_utils.json_loads(open(filename, "r").read())
@@ -315,7 +309,7 @@ def run_tasks(
             click.echo(table.table)
         else:
             table_data = [
-                ["Action", "Params", "Duration"],
+                ["Action", "Params", "Duration", "Result"],
             ]
             table = terminaltables.AsciiTable(table_data)
             for filename in glob("results/success/*.json") + glob(
@@ -346,7 +340,12 @@ def run_tasks(
                 params = yaml.safe_dump(params)
 
                 table_data.append(
-                    [result.get("task_type"), params, result.get("duration"),]
+                    [
+                        result.get("task_type"),
+                        params,
+                        result.get("duration"),
+                        result.get("event_type"),
+                    ]
                 )
             click.echo(table.table)
             for filename in glob("results/failure/*.json"):
