@@ -31,7 +31,7 @@ class TerminateDryRunWorkspaceTask(tasks.TaskWithParameters):
     requested_priority = luigi.IntParameter(significant=False, default=0)
 
     execution = luigi.Parameter()
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     def params_for_results_display(self):
         return {
