@@ -34,7 +34,7 @@ class TerminateWorkspaceTask(tasks.TaskWithParameters):
     manifest_file_path = luigi.Parameter()
 
     section_name = constants.WORKSPACES
-    cachable_level = constants.CACHE_LEVEL_NORMAL
+    cachable_level = constants.CACHE_LEVEL_RUN
 
     @property
     def item_name(self):
